[committed] strcoll_l, strxfrm_l are standardized now

Message ID 2e800fd9-8c39-7794-b0b7-7461de170cdf@panix.com
State Committed
Headers

Commit Message

Zack Weinberg Nov. 16, 2016, 7:47 p.m. UTC
  I have checked in the following patch, which corrects comments in
string.h.  strcoll_l and strxfrm_l are in POSIX.1-2008, and are
correctly under #ifdef __USE_XOPEN2K8, but the comments say that they
have not yet been standardized.

zw

	* string/string.h: Remove obsolete comment stating that
	strcoll_l and strxfrm_l have not yet been standardized.
  

Patch

diff --git a/string/string.h b/string/string.h
index 57deaa4..b103e64 100644
--- a/string/string.h
+++ b/string/string.h
@@ -154,15 +154,13 @@  extern size_t strxfrm (char *__restrict __dest,
 __END_NAMESPACE_STD

 #ifdef __USE_XOPEN2K8
-/* The following functions are equivalent to the both above but they
-   take the locale they use for the collation as an extra argument.
-   This is not standardsized but something like will come.  */
 # include <xlocale.h>

 /* Compare the collated forms of S1 and S2 using rules from L.  */
 extern int strcoll_l (const char *__s1, const char *__s2, __locale_t __l)
      __THROW __attribute_pure__ __nonnull ((1, 2, 3));
-/* Put a transformation of SRC into no more than N bytes of DEST.  */
+/* Put a transformation of SRC into no more than N bytes of DEST,
+   using sorting rules from L.  */
 extern size_t strxfrm_l (char *__dest, const char *__src, size_t __n,
                         __locale_t __l) __THROW __nonnull ((2, 4));
 #endif
@@ -154,15 +154,13 @@  extern size_t strxfrm (char *__restrict __dest,
 # include <xlocale.h>

-/* Compare the collated forms of S1 and S2 using rules from L.  */
+/* Compare the collated forms of S1 and S2, using sorting rules from L.  */
 extern int strcoll_l (const char *__s1, const char *__s2, __locale_t __l)
      __THROW __attribute_pure__ __nonnull ((1, 2, 3));